#
# spec file for package python-altair-widgets
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         skip_python39 1
# The test suite is not packaged in the PyPI package. The tests available on
# GitHub require pytest-ipynb which is not available on openSUSE and was
# abandoned upstream
%bcond_with     test
Name:           python-altair-widgets
Version:        0.2.2
Release:        4.5
Summary:        Interactive visualization package for statistical data for Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            http://altair-viz.github.io
Source:         https://files.pythonhosted.org/packages/source/a/altair_widgets/altair_widgets-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-altair >= 2.0.0
Requires:       python-ipython
Requires:       python-ipywidgets >= 7.0.0
Requires:       python-pandas
Requires:       python-vega >= 0.4.4
Provides:       python-jupyter_altair-widgets = %{version}
Obsoletes:      python-jupyter_altair-widgets <= %{version}
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module altair >= 2.0.0}
BuildRequires:  %{python_module ipython}
BuildRequires:  %{python_module ipywidgets >= 7.0.0}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module pytest-ipynb}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module vega >= 0.4.4}
%endif
%if "%{python_flavor}" == "python3" || "%{?python_provides}"  == "python3"
Provides:       jupyter-altair-widgets = %{version}
%endif
%python_subpackages

%description
This package provides interactive data visualization tools in the Jupyter
Notebook.

The interactive visualization tool that is provided allows data selection
through HTML widgets and outputs a Vega-lite plot through Altair. In the HTML
widget it is possible to select columns to plot in various encodings. This
widget also supports some basic configuration (i.e., log vs linear scales).

%prep
%setup -q -n altair_widgets-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with test}
%check
%pytest altair_widgets
%endif

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/altair_widgets/
%{python_sitelib}/altair_widgets-%{version}-py*.egg-info

%changelog
* Tue Mar  5 2024 Ben Greiner <code@bnavigator.de>
- Skip python39: no longer supported since ipython 8.19
* Fri May 28 2021 Steve Kowalik <steven.kowalik@suse.com>
- Do not build for Python 3.6, due to no NumPy.
* Tue Dec 15 2020 Benjamin Greiner <code@bnavigator.de>
- Provide the old jupyter package name only for the primary
  Python3 interpreter -- gh#openSUSE/python-rpm-macros#66
- Add explanation about skipped testsuite
* Wed Nov 27 2019 Todd R <toddrme2178@gmail.com>
- Drop python2 support due to missing python2 support in dependencies.
* Tue Nov 12 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.2.2
  * MAINT: get working with latest versions of Altair and ipywidgets
  * BUG: work with current versions of altair and ipywidgets
  * Instead of using a hard-coded list, pull the channels from altair API
  * MAINT: disable options button
  * Pulling functions from the altair API
  * Pulling mark names from the altair API
  * Pulling the typecodes from the altair API
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Rename to to match python package naming guidelines.
* Thu May  3 2018 toddrme2178@gmail.com
- Use %%license tag
* Tue Sep 19 2017 toddrme2178@gmail.com
- Add documentation and license
* Tue Aug 22 2017 toddrme2178@gmail.com
- Initial version
